@@ -22,10 +22,8 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 
 #include <stdio.h>  
-//#include <stdlib.h>
-//#include <sys/timeb.h> 
- 
 #include <string.h>
+#include <Basic_utils.h>
 #include "error.h"
 
 #ifdef DO_PARALLEL
