@@ -24,8 +24,6 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #ifndef RFxport_H
 #define RFxport_H 1
 
-#include <zzz_RandomFieldsUtils.h>
-
 #define UTILSCALLS \
   CALL(getErrorString);				\
   CALL(setErrorLoc);				\
@@ -35,12 +33,6 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
   CALL(relaxUnknownRFoption);			\
   CALL(scalarX)
 
-#ifdef CALL
-#undef CALL
-#endif
-#define CALL(what) extern what##_type Ext_##what
-UTILSCALLS;
 
 void includeXport();
-extern utilsparam* GLOBAL_UTILS;
 #endif
